@@ -3,7 +3,7 @@
    Lexical scanner for dhcpd config file... */
 
 /*
- * Copyright (c) 2004-2015 by Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (c) 2004-2016 by Internet Systems Consortium, Inc. ("ISC")
  * Copyright (c) 1995-2003 by Internet Software Consortium
  *
  * Permission to use, copy, modify, and distribute this software for any
@@ -783,6 +783,8 @@ intern(char *atom, enum dhcp_token dfv) {
 				return ATSFP;
 			break;
 		}
+		if (!strcasecmp(atom + 1, "uthoring-byte-order"))
+			return AUTHORING_BYTE_ORDER;
 		if (!strncasecmp(atom + 1, "ut", 2)) {
 			if (isascii(atom[3]) &&
 			    (tolower((unsigned char)atom[3]) == 'h')) {
@@ -827,6 +829,9 @@ intern(char *atom, enum dhcp_token dfv) {
 			return BALANCE;
 		if (!strcasecmp (atom + 1, "ound"))
 			return BOUND;
+		if (!strcasecmp(atom+1, "ig-endian")) {
+			return TOKEN_BIG_ENDIAN;
+		}
 		if (!strcasecmp (atom + 1, "ootp-broadcast-always"))
 			return BOOTP_BROADCAST_ALWAYS;
 		break;
@@ -1047,6 +1052,9 @@ intern(char *atom, enum dhcp_token dfv) {
 			return HOSTNAME;
 		if (!strcasecmp (atom + 1, "elp"))
 			return TOKEN_HELP;
+		if (!strcasecmp (atom + 1, "ex")) {
+			return TOKEN_HEX;
+		}
 		break;
 	      case 'i':
 	      	if (!strcasecmp(atom+1, "a-na")) 
@@ -1130,6 +1138,12 @@ intern(char *atom, enum dhcp_token dfv) {
 		if (!strcasecmp(atom+1, "l")) {
 			return LL;
 		}
+		if (!strcasecmp(atom+1, "ittle-endian")) {
+			return TOKEN_LITTLE_ENDIAN;
+		}
+		if (!strcasecmp (atom + 1, "ease-id-format")) {
+			return LEASE_ID_FORMAT;
+		}
 		break;
 	      case 'm':
 		if (!strncasecmp (atom + 1, "ax", 2)) {
@@ -1230,6 +1244,9 @@ intern(char *atom, enum dhcp_token dfv) {
 			return OF;
 		if (!strcasecmp (atom + 1, "wner"))
 			return OWNER;
+		if (!strcasecmp (atom + 1, "ctal")) {
+			return TOKEN_OCTAL;
+		}
 		break;
 	      case 'p':
 		if (!strcasecmp (atom + 1, "arse-vendor-option"))
