@@ -1145,7 +1145,9 @@ void maybe_setup_fallback ()
 #if defined(sun) && defined(USE_V4_PKTINFO)
 /* This code assumes the existence of SIOCGLIFHWADDR */
 void
-get_hw_addr(const char *name, struct hardware *hw) {
+get_hw_addr(struct interface_info *info) {
+	struct hardware *hw = &info->hw_address;
+	const char *name = info->name;
 	struct sockaddr_dl *dladdrp;
 	int sock, i;
 	struct lifreq lifr;
